#[repr(C)]pub struct Inset {
pub top: i32,
pub right: i32,
pub bottom: i32,
pub left: i32,
}Expand description
An integer offset to apply to each edge of a rectangle.
This type does not specify units. Protocols that use this type should specify the characteristics of the vector space, including orientation and units.
Fields
top: i32right: i32bottom: i32left: i32Trait Implementations
Sourceimpl<'a, ___E> Encode<Inset, ___E> for &'a Insetwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Inset, ___E> for &'a Insetwhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<Inset, ___E> for Insetwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Inset, ___E> for Insetwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, Inset>
const COPY_OPTIMIZATION: CopyOptimization<Self, Inset>
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Inset>, ___E> for &'a Inset
impl<'a, ___E> EncodeOption<Box<'static, Inset>, ___E> for &'a Inset
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Inset>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Inset>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Inset>, ___E> for Inset
impl<___E> EncodeOption<Box<'static, Inset>, ___E> for Inset
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Inset>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Inset>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWireRef<Inset> for Inset
impl FromWireRef<Inset> for Inset
Sourcefn from_wire_ref(wire: &Inset) -> Self
fn from_wire_ref(wire: &Inset) -> Self
Converts the given reference to this type.
Sourceimpl Ord for Inset
impl Ord for Inset
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for Inset
impl PartialOrd for Inset
impl Copy for Inset
impl Eq for Inset
impl StructuralPartialEq for Inset