#[repr(C)]pub struct InsetF {
pub top: f32,
pub right: f32,
pub bottom: f32,
pub left: f32,
}Expand description
A floating point offset to apply to each edge of a rectangle.
This type does not specify units. Protocols that use this type should specify the characteristics of the vector space, including orientation and units.
Fields
top: f32right: f32bottom: f32left: f32Trait Implementations
Sourceimpl<'a, ___E> Encode<InsetF, ___E> for &'a InsetFwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<InsetF, ___E> for &'a InsetFwhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<InsetF, ___E> for InsetFwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<InsetF, ___E> for InsetFwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, InsetF>
const COPY_OPTIMIZATION: CopyOptimization<Self, InsetF>
Sourceimpl<'a, ___E> EncodeOption<Box<'static, InsetF>, ___E> for &'a InsetF
impl<'a, ___E> EncodeOption<Box<'static, InsetF>, ___E> for &'a InsetF
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, InsetF>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, InsetF>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, InsetF>, ___E> for InsetF
impl<___E> EncodeOption<Box<'static, InsetF>, ___E> for InsetF
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, InsetF>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, InsetF>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWireRef<InsetF> for InsetF
impl FromWireRef<InsetF> for InsetF
Sourcefn from_wire_ref(wire: &InsetF) -> Self
fn from_wire_ref(wire: &InsetF) -> Self
Converts the given reference to this type.
Sourceimpl PartialOrd for InsetF
impl PartialOrd for InsetF
impl Copy for InsetF
impl StructuralPartialEq for InsetF