#[repr(C)]pub struct Point {
pub x: i32,
pub y: i32,
}Expand description
An integer position in a 2D cartesian space.
This type does not specify units. Protocols that use this type should specify the characteristics of the vector space, including orientation and units.
Fields
x: i32y: i32Trait Implementations
Sourceimpl<'a, ___E> Encode<Point, ___E> for &'a Pointwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Point, ___E> for &'a Pointwhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<Point, ___E> for Pointwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Point, ___E> for Pointwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, Point>
const COPY_OPTIMIZATION: CopyOptimization<Self, Point>
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Point>, ___E> for &'a Point
impl<'a, ___E> EncodeOption<Box<'static, Point>, ___E> for &'a Point
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Point>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Point>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Point>, ___E> for Point
impl<___E> EncodeOption<Box<'static, Point>, ___E> for Point
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Point>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Point>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWireRef<Point> for Point
impl FromWireRef<Point> for Point
Sourcefn from_wire_ref(wire: &Point) -> Self
fn from_wire_ref(wire: &Point) -> Self
Converts the given reference to this type.
Sourceimpl Ord for Point
impl Ord for Point
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for Point
impl PartialOrd for Point
impl Copy for Point
impl Eq for Point
impl StructuralPartialEq for Point