#[repr(C)]pub struct Point3F {
pub x: f32,
pub y: f32,
pub z: f32,
}Expand description
A floating point position in a 3D cartesian space.
This type does not specify units. Protocols that use this type should specify the characteristics of the vector space, including orientation and units.
Fields
x: f32y: f32z: f32Trait Implementations
Sourceimpl<'a, ___E> Encode<Point3F, ___E> for &'a Point3Fwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Point3F, ___E> for &'a Point3Fwhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<Point3F, ___E> for Point3Fwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Point3F, ___E> for Point3Fwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, Point3F>
const COPY_OPTIMIZATION: CopyOptimization<Self, Point3F>
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Point3F>, ___E> for &'a Point3F
impl<'a, ___E> EncodeOption<Box<'static, Point3F>, ___E> for &'a Point3F
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Point3F>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Point3F>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Point3F>, ___E> for Point3F
impl<___E> EncodeOption<Box<'static, Point3F>, ___E> for Point3F
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Point3F>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Point3F>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWireRef<Point3F> for Point3F
impl FromWireRef<Point3F> for Point3F
Sourcefn from_wire_ref(wire: &Point3F) -> Self
fn from_wire_ref(wire: &Point3F) -> Self
Converts the given reference to this type.
Sourceimpl PartialOrd for Point3F
impl PartialOrd for Point3F
impl Copy for Point3F
impl StructuralPartialEq for Point3F