#[repr(C)]pub struct PointF {
pub x: f32,
pub y: f32,
}Expand description
A floating point position in a 2D cartesian space.
This type does not specify units. Protocols that use this type should specify the characteristics of the vector space, including orientation and units.
Fields
x: f32y: f32Trait Implementations
Sourceimpl<'a, ___E> Encode<PointF, ___E> for &'a PointFwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<PointF, ___E> for &'a PointFwhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<PointF, ___E> for PointFwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<PointF, ___E> for PointFwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, PointF>
const COPY_OPTIMIZATION: CopyOptimization<Self, PointF>
Sourceimpl<'a, ___E> EncodeOption<Box<'static, PointF>, ___E> for &'a PointF
impl<'a, ___E> EncodeOption<Box<'static, PointF>, ___E> for &'a PointF
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PointF>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PointF>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, PointF>, ___E> for PointF
impl<___E> EncodeOption<Box<'static, PointF>, ___E> for PointF
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PointF>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PointF>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWireRef<PointF> for PointF
impl FromWireRef<PointF> for PointF
Sourcefn from_wire_ref(wire: &PointF) -> Self
fn from_wire_ref(wire: &PointF) -> Self
Converts the given reference to this type.
Sourceimpl PartialOrd for PointF
impl PartialOrd for PointF
impl Copy for PointF
impl StructuralPartialEq for PointF