#[repr(C)]pub struct RRectF {
pub x: f32,
pub y: f32,
pub width: f32,
pub height: f32,
pub top_left_radius_x: f32,
pub top_left_radius_y: f32,
pub top_right_radius_x: f32,
pub top_right_radius_y: f32,
pub bottom_left_radius_x: f32,
pub bottom_left_radius_y: f32,
pub bottom_right_radius_x: f32,
pub bottom_right_radius_y: f32,
}Expand description
A floating point rounded rectangle with the custom radii for all four corners.
A region in a 2D cartesian space consisting of linear, axis-aligned sides with corners rounded into a quarter ellipse.
If the quarter ellipses in two corners would overlap, their radii are clamped such that the ellipses meet with an axis-aligned tangent.
This type does not specify units. Protocols that use this type should specify the characteristics of the vector space, including orientation and units.
Fields
x: f32y: f32width: f32height: f32top_left_radius_x: f32top_left_radius_y: f32top_right_radius_x: f32top_right_radius_y: f32bottom_left_radius_x: f32bottom_left_radius_y: f32bottom_right_radius_x: f32bottom_right_radius_y: f32Trait Implementations
Sourceimpl<'a, ___E> Encode<RRectF, ___E> for &'a RRectFwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<RRectF, ___E> for &'a RRectFwhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<RRectF, ___E> for RRectFwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<RRectF, ___E> for RRectFwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, RRectF>
const COPY_OPTIMIZATION: CopyOptimization<Self, RRectF>
Sourceimpl<'a, ___E> EncodeOption<Box<'static, RRectF>, ___E> for &'a RRectF
impl<'a, ___E> EncodeOption<Box<'static, RRectF>, ___E> for &'a RRectF
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, RRectF>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, RRectF>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, RRectF>, ___E> for RRectF
impl<___E> EncodeOption<Box<'static, RRectF>, ___E> for RRectF
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, RRectF>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, RRectF>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWireRef<RRectF> for RRectF
impl FromWireRef<RRectF> for RRectF
Sourcefn from_wire_ref(wire: &RRectF) -> Self
fn from_wire_ref(wire: &RRectF) -> Self
Converts the given reference to this type.
Sourceimpl PartialOrd for RRectF
impl PartialOrd for RRectF
impl Copy for RRectF
impl StructuralPartialEq for RRectF