#[repr(C)]pub struct RatioU32 {
pub numerator: u32,
pub denominator: u32,
}Expand description
A ratio of unsigned 32-bit numbers.
Fields
numerator: u32denominator: u32Trait Implementations
Sourceimpl<'a, ___E> Encode<RatioU32, ___E> for &'a RatioU32where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<RatioU32, ___E> for &'a RatioU32where
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<RatioU32, ___E> for RatioU32where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<RatioU32, ___E> for RatioU32where
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, RatioU32>
const COPY_OPTIMIZATION: CopyOptimization<Self, RatioU32>
Sourceimpl<'a, ___E> EncodeOption<Box<'static, RatioU32>, ___E> for &'a RatioU32
impl<'a, ___E> EncodeOption<Box<'static, RatioU32>, ___E> for &'a RatioU32
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, RatioU32>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, RatioU32>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, RatioU32>, ___E> for RatioU32
impl<___E> EncodeOption<Box<'static, RatioU32>, ___E> for RatioU32
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, RatioU32>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, RatioU32>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWireRef<RatioU32> for RatioU32
impl FromWireRef<RatioU32> for RatioU32
Sourcefn from_wire_ref(wire: &RatioU32) -> Self
fn from_wire_ref(wire: &RatioU32) -> Self
Converts the given reference to this type.
Sourceimpl Ord for RatioU32
impl Ord for RatioU32
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for RatioU32
impl PartialOrd for RatioU32
impl Copy for RatioU32
impl Eq for RatioU32
impl StructuralPartialEq for RatioU32