SizeF

Struct SizeF 

#[repr(C)]
pub struct SizeF { pub width: f32, pub height: f32, }
The floating point dimensions of a rectangular region in a 2D cartesian space.

This type does not specify units. Protocols that use this type should specify the characteristics of the vector space, including orientation and units.

This type allows for negative dimensions, to which protocols can give semantics. Protocols that use this type should specify whether negative dimensions are meaningful, and, if they are meaningful, what they mean.

Fields

width: f32height: f32