#[repr(C)]pub struct SizeU {
pub width: u32,
pub height: u32,
}Expand description
The unsigned integer dimensions of a rectangular region in a 2D cartesian space.
This type does not specify units. Protocols that use this type should specify the characteristics of the vector space, including orientation and units.
Fields
width: u32height: u32Trait Implementations
Sourceimpl<'a, ___E> Encode<SizeU, ___E> for &'a SizeUwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SizeU, ___E> for &'a SizeUwhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<SizeU, ___E> for SizeUwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SizeU, ___E> for SizeUwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, SizeU>
const COPY_OPTIMIZATION: CopyOptimization<Self, SizeU>
Sourceimpl<'a, ___E> EncodeOption<Box<'static, SizeU>, ___E> for &'a SizeU
impl<'a, ___E> EncodeOption<Box<'static, SizeU>, ___E> for &'a SizeU
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SizeU>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SizeU>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, SizeU>, ___E> for SizeU
impl<___E> EncodeOption<Box<'static, SizeU>, ___E> for SizeU
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SizeU>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SizeU>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWireRef<SizeU> for SizeU
impl FromWireRef<SizeU> for SizeU
Sourcefn from_wire_ref(wire: &SizeU) -> Self
fn from_wire_ref(wire: &SizeU) -> Self
Converts the given reference to this type.
Sourceimpl Ord for SizeU
impl Ord for SizeU
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for SizeU
impl PartialOrd for SizeU
impl Copy for SizeU
impl Eq for SizeU
impl StructuralPartialEq for SizeU