#[repr(C)]pub struct Transform {
pub matrix: [f32; 16],
}Expand description
A projective transformation of a 3D cartesian space.
A transform consists of a 4x4 matrix that operates in homogeneous
coordinates. For example, a point located at (x, y, z) in the cartesian
space is transformed by M to a point located at (x’/w’, y’/w’, z’/w’),
where (x', y', z', w') = M (x, y, z, 1).
Fields
matrix: [f32; 16]Trait Implementations
Sourceimpl<'a, ___E> Encode<Transform, ___E> for &'a Transformwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Transform, ___E> for &'a Transformwhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<Transform, ___E> for Transformwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Transform, ___E> for Transformwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, Transform>
const COPY_OPTIMIZATION: CopyOptimization<Self, Transform>
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Transform>, ___E> for &'a Transform
impl<'a, ___E> EncodeOption<Box<'static, Transform>, ___E> for &'a Transform
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Transform>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Transform>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Transform>, ___E> for Transform
impl<___E> EncodeOption<Box<'static, Transform>, ___E> for Transform
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Transform>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Transform>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWireRef<Transform> for Transform
impl FromWireRef<Transform> for Transform
Sourcefn from_wire_ref(wire: &Transform) -> Self
fn from_wire_ref(wire: &Transform) -> Self
Converts the given reference to this type.
Sourceimpl PartialOrd for Transform
impl PartialOrd for Transform
impl Copy for Transform
impl StructuralPartialEq for Transform