#[repr(C)]pub struct Vec4F {
pub x: f32,
pub y: f32,
pub z: f32,
pub w: f32,
}Expand description
Represents a 4D vector with floating point coordinates.
This type does not specify units. Protocols that use this type should specify the characteristics of the vector space, including orientation and units.
Fields
x: f32y: f32z: f32w: f32Trait Implementations
Sourceimpl<'a, ___E> Encode<Vec4F, ___E> for &'a Vec4Fwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Vec4F, ___E> for &'a Vec4Fwhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<Vec4F, ___E> for Vec4Fwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Vec4F, ___E> for Vec4Fwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, Vec4F>
const COPY_OPTIMIZATION: CopyOptimization<Self, Vec4F>
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Vec4F>, ___E> for &'a Vec4F
impl<'a, ___E> EncodeOption<Box<'static, Vec4F>, ___E> for &'a Vec4F
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Vec4F>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Vec4F>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Vec4F>, ___E> for Vec4F
impl<___E> EncodeOption<Box<'static, Vec4F>, ___E> for Vec4F
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Vec4F>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Vec4F>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWireRef<Vec4F> for Vec4F
impl FromWireRef<Vec4F> for Vec4F
Sourcefn from_wire_ref(wire: &Vec4F) -> Self
fn from_wire_ref(wire: &Vec4F) -> Self
Converts the given reference to this type.
Sourceimpl PartialOrd for Vec4F
impl PartialOrd for Vec4F
impl Copy for Vec4F
impl StructuralPartialEq for Vec4F