#[repr(C)]pub struct VecF {
pub x: f32,
pub y: f32,
}Expand description
Represents a 2D vector with floating point coordinates.
This type does not specify units. Protocols that use this type should specify the characteristics of the vector space, including orientation and units.
Fields
x: f32y: f32Trait Implementations
Sourceimpl<'a, ___E> Encode<VecF, ___E> for &'a VecFwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<VecF, ___E> for &'a VecFwhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<VecF, ___E> for VecFwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<VecF, ___E> for VecFwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, VecF>
const COPY_OPTIMIZATION: CopyOptimization<Self, VecF>
Sourceimpl<'a, ___E> EncodeOption<Box<'static, VecF>, ___E> for &'a VecF
impl<'a, ___E> EncodeOption<Box<'static, VecF>, ___E> for &'a VecF
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, VecF>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, VecF>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, VecF>, ___E> for VecF
impl<___E> EncodeOption<Box<'static, VecF>, ___E> for VecF
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, VecF>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, VecF>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWireRef<VecF> for VecF
impl FromWireRef<VecF> for VecF
Sourcefn from_wire_ref(wire: &VecF) -> Self
fn from_wire_ref(wire: &VecF) -> Self
Converts the given reference to this type.
Sourceimpl PartialOrd for VecF
impl PartialOrd for VecF
impl Copy for VecF
impl StructuralPartialEq for VecF